@@ -6,10 +6,84 @@ use namespace::autoclean;
 
 use Bubblegum::Namespace;
 use Class::Load 'load_class';
+use Types::Standard ();
 
 our @ISA = (); # non-object
 
-our $VERSION = '0.32'; # VERSION
+our $VERSION = '0.33'; # VERSION
+
+*asa_aref       = \&Types::Standard::assert_ArrayRef;
+*asa_arrayref   = \&Types::Standard::assert_ArrayRef;
+*asa_bool       = \&Types::Standard::assert_Bool;
+*asa_boolean    = \&Types::Standard::assert_Bool;
+*asa_class      = \&Types::Standard::assert_ClassName;
+*asa_classname  = \&Types::Standard::assert_ClassName;
+*asa_coderef    = \&Types::Standard::assert_CodeRef;
+*asa_cref       = \&Types::Standard::assert_CodeRef;
+*asa_def        = \&Types::Standard::assert_Defined;
+*asa_defined    = \&Types::Standard::assert_Defined;
+*asa_fh         = \&Types::Standard::assert_FileHandle;
+*asa_filehandle = \&Types::Standard::assert_FileHandle;
+*asa_glob       = \&Types::Standard::assert_GlobRef;
+*asa_globref    = \&Types::Standard::assert_GlobRef;
+*asa_hashref    = \&Types::Standard::assert_HashRef;
+*asa_href       = \&Types::Standard::assert_HashRef;
+*asa_int        = \&Types::Standard::assert_Int;
+*asa_integer    = \&Types::Standard::assert_Int;
+*asa_nil        = \&Types::Standard::assert_Undef;
+*asa_null       = \&Types::Standard::assert_Undef;
+*asa_num        = \&Types::Standard::assert_Num;
+*asa_number     = \&Types::Standard::assert_Num;
+*asa_obj        = \&Types::Standard::assert_Object;
+*asa_object     = \&Types::Standard::assert_Object;
+*asa_ref        = \&Types::Standard::assert_Ref;
+*asa_reference  = \&Types::Standard::assert_Ref;
+*asa_regexpref  = \&Types::Standard::assert_RegexpRef;
+*asa_rref       = \&Types::Standard::assert_RegexpRef;
+*asa_scalarref  = \&Types::Standard::assert_ScalarRef;
+*asa_sref       = \&Types::Standard::assert_ScalarRef;
+*asa_str        = \&Types::Standard::assert_Str;
+*asa_string     = \&Types::Standard::assert_Str;
+*asa_undef      = \&Types::Standard::assert_Undef;
+*asa_undefined  = \&Types::Standard::assert_Undef;
+*asa_val        = \&Types::Standard::assert_Value;
+*asa_value      = \&Types::Standard::assert_Value;
+*isa_aref       = \&Types::Standard::is_ArrayRef;
+*isa_arrayref   = \&Types::Standard::is_ArrayRef;
+*isa_bool       = \&Types::Standard::is_Bool;
+*isa_boolean    = \&Types::Standard::is_Bool;
+*isa_class      = \&Types::Standard::is_ClassName;
+*isa_classname  = \&Types::Standard::is_ClassName;
+*isa_coderef    = \&Types::Standard::is_CodeRef;
+*isa_cref       = \&Types::Standard::is_CodeRef;
+*isa_def        = \&Types::Standard::is_Defined;
+*isa_defined    = \&Types::Standard::is_Defined;
+*isa_fh         = \&Types::Standard::is_FileHandle;
+*isa_filehandle = \&Types::Standard::is_FileHandle;
+*isa_glob       = \&Types::Standard::is_GlobRef;
+*isa_globref    = \&Types::Standard::is_GlobRef;
+*isa_hashref    = \&Types::Standard::is_HashRef;
+*isa_href       = \&Types::Standard::is_HashRef;
+*isa_int        = \&Types::Standard::is_Int;
+*isa_integer    = \&Types::Standard::is_Int;
+*isa_nil        = \&Types::Standard::is_Undef;
+*isa_null       = \&Types::Standard::is_Undef;
+*isa_num        = \&Types::Standard::is_Num;
+*isa_number     = \&Types::Standard::is_Num;
+*isa_obj        = \&Types::Standard::is_Object;
+*isa_object     = \&Types::Standard::is_Object;
+*isa_ref        = \&Types::Standard::is_Ref;
+*isa_reference  = \&Types::Standard::is_Ref;
+*isa_regexpref  = \&Types::Standard::is_RegexpRef;
+*isa_rref       = \&Types::Standard::is_RegexpRef;
+*isa_scalarref  = \&Types::Standard::is_ScalarRef;
+*isa_sref       = \&Types::Standard::is_ScalarRef;
+*isa_str        = \&Types::Standard::is_Str;
+*isa_string     = \&Types::Standard::is_Str;
+*isa_undef      = \&Types::Standard::is_Undef;
+*isa_undefined  = \&Types::Standard::is_Undef;
+*isa_val        = \&Types::Standard::is_Value;
+*isa_value      = \&Types::Standard::is_Value;
 
 sub digest {
     my $self  = CORE::shift;
@@ -63,7 +137,7 @@ Bubblegum::Object::Universal - Common Methods for Operating on Defined Values
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -161,8 +235,6 @@ The yaml method blesses the subject into the wrapper class,
 L<Bubblegum::Wrapper::Yaml>, and returns an instance. Please see
 L<Bubblegum::Wrapper::Yaml> for more information.
 
-=encoding utf8
-
 =head1 TYPE ASSERTION METHODS
 
 All data type objects have access to type assertions methods which can be call
